.. _functional_alignment:

=====================================================
Functional alignment: handling functional variability
=====================================================

Functional alignment seek to handle functional variablity by learning a transformation
from one subject to another. It can be useful to better transfer knowledge of
functional characteristics across subjects or to improve `decoding <https://nilearn.github.io/decoding/index.html>`_

.. toctree::

   introduction.rst
   fmralign_pipeline.rst
